@@ -22,6 +22,7 @@ import asyncio
 import functools
 import pyrogram
 import typing
+import re
 
 from ..utils import patch, patchable
 
@@ -31,6 +32,10 @@ class ListenerCanceled(Exception):
     pass
 pyrogram.errors.ListenerCanceled = ListenerCanceled
 
+pyrogram.client.Client.USERNAME_LINK_RE = re.compile(
+    '^(?:https?://)?(?:www\\.)?(?:t(?:elegram)?\\.(?:org|me|dog)/)([a-zA-Z0-9_]+)$'
+)
+
 class Client():
     @patchable
     def __init__(self, *args, **kwargs):
